@@ -186,6 +186,8 @@ class Impeller:
             "power",
             "psi",
             "phi",
+            "flow_v",
+            "flow_m",
         ]:
             values = []
             # for disch.p etc values are defined in _Impeller_State
@@ -282,6 +284,15 @@ class Impeller:
         """
         speeds = np.array([curve.speed.magnitude for curve in self.curves])
 
+        # handle case where we only have one curve and can't interpolate
+        if len(speeds) == 1:
+            current_curve = self.curves[0]
+            if speed is not None and speed != current_curve.speed:
+                raise ValueError(
+                    f"Can only interpolate for speed={current_curve.speed}"
+                )
+            return current_curve
+
         closest_curves_idxs = find_closest_speeds(speeds, speed.magnitude)
         curves = [
             self.curves[closest_curves_idxs[0]],
@@ -361,6 +372,8 @@ class Impeller:
 
                 if speed is None:
                     speed_mean = np.mean([p.speed.magnitude for p in converted_points])
+                else:
+                    speed_mean = speed
 
                 converted_points = [
                     Point.convert_from(
@@ -882,7 +895,7 @@ class Impeller:
              Default is interp1d.
         """
         curves_path_dict = {}
-        args = locals()
+
         for param in ["head", "eff", "power", "pressure_ratio", "disch_T"]:
             param_path = curve_path / (curve_name + f"-{param}.csv")
             if param_path.is_file():
